/***************************************************************************************
Copyright (c) 2012 Michael Pozhidaev <msp@altlinux.org>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**************************************************************************************************/

#ifndef MINISAT_H
#define MINISAT_H

#include<string.h>

#ifdef __cplusplus
#define MINISAT_DECL extern "C"
#else
#define MINISAT_DECL
#endif //__cplusplus;

#define MINISAT_OK 0
#define MINISAT_UNSAT 1
#define MINISAT_INVALID_DATA 2
#define MINISAT_INTERNAL_PROBLEM 3

/*
 * Each variable for the function below is represented as integer between
 * 1 and varCount (including both of them) where varCount is the total number of variables. The negative value
 * means an inversed literal. Each of the litCounts and clauses array
 * should have clauseCount items. Each element of the clauses array should
 * have number of items equal to corresponding element of litCounts. The
 * result is returned through res array which should contain varCOunt + 1
 * items. Zero item always left unchanged.
 *
 * In case of MINISAT_UNSAT result the collisions array contains marks
 * what variables have come to a collision status. The format of the
 * collisions array is similar to the res one.
 */
MINISAT_DECL int minisat_solve(size_t varCount,
			       size_t clauseCount,
			       size_t* litCounts,
			       int* clauses[],
			       unsigned char* res,
			       unsigned char* collision);

#endif //MINISAT_H;
